<?php

namespace Aimeos\MShop\Order\Manager;

use App\Models\Order;

class CustomOrderManager extends Standard
{
    private $searchConfig = [
        'order.order_no' => [
            'code' => 'order.order_no',
            'internalcode' => 'mord."order_no"',
            'label' => 'Order number',
            'type' => 'string', // integer, float, etc.
        ],
    ];

    protected function saveBase(\Aimeos\MShop\Common\Item\Iface $item, bool $fetch = true): \Aimeos\MShop\Common\Item\Iface
    {
        if (!empty($item->getId()) && empty($item->getOrderNo())) {
            $context = $this->context();
            $siteCode = $context->locale()->getSiteCode();
            $item->setOrderNo(Order::createOrderNumber($item->getId(), $siteCode));
        }

        return parent::saveBase($item, $fetch);
    }

    public function getSearchAttributes(bool $withsub = true): array
    {
        return parent::getSearchAttributes($withsub)
            + $this->createAttributes($this->searchConfig);
    }

    public function create(array $values = []): \Aimeos\MShop\Common\Item\Iface
    {
        $context = $this->context();
        $locale = $context->locale();

        $values['.locale'] = $values['.locale'] ?? $locale;
        $values['.price'] = $values['.price'] ?? \Aimeos\MShop::create($context, 'price')->create();
        $values['order.siteid'] = $values['order.siteid'] ?? $locale->getSiteId();

        $item = new \Aimeos\MShop\Order\Item\CustomOrderItem('order.', $values);
        \Aimeos\MShop::create($context, 'plugin')->register($item, 'order');

        return $item;
    }

}
